To speed up how is_key is applied in the first, second, and third_normal function

is_key_cached(data, cols, key_cache)

Arguments

data

data frame

cols

list

Value

True or False depending on whether the column is a key of the data or not