Reduces the amount of keys being stored by reducing redundant information

no_duplicates_cached(data, cols, key_cache)

Arguments

data

data frame

cols

list

Value

True or False depending on whether the subset is a duplicate of another subset that has already been cached