Function to check whether a dataset is in third normal form

third_normal(data, max_size = 2)

Arguments

data

data frame

max_size

maximum size of the key

Value

logical value: `TRUE`, if the data is in first normal form, `FALSE` otherwise

Details

If `FALSE` is returned, one of two messages will print: - `"Dataset is NOT in Third Normal Form because it is not in Second Normal Form"` (when data is not in second normal form) - `"Transitive dependency detected"` (when one column depends on a non-key column)

Examples

third_normal(auto, max_size=2)
#> [1] "FALSE: Dataset is NOT in Third Normal Form because it is not in Second Normal Form"