auto.RdA data set that contains common performance metrics for cars based off make and model.
autoThe data is 398 rows of 11 variables
The data came from The R Project for Statistical Computing website at https://search.r-project.org/CRAN/refmans/ISLR2/html/Auto.html which includes a link to the original publishing site https://www.statlearning.com/