is_key.Rd
Assess whether a proposed set of variables is a key
is_key(data, cols)
A data frame or tibble
A character vector of column names to be considered as a key
Logical value: `TRUE` if the specified column combination is a key, `FALSE` otherwise
data(college) is_key(college, "city") #> [1] FALSE