second_normal.Rdfunction to check whether a dataset is in second normal form
second_normal(data, max_size = 2)`TRUE` if the data is in second normal form, `FALSE` otherwise
If `FALSE` is returned, one of two messages will print: - `"Dataset is NOT in First Normal Form, no candidate key exists"` (when no column(s) are keys) - `"Dataset is NOT in First Normal Form, non-atomic columns found"` (when one or more columns include contain multiple values in the same row)
second_normal(auto, max_size = 2)
#> [1] "FALSE: Dataset is NOT in Second Normal Form because it is not in First Normal Form"