third_normal.RdFunction to check whether a dataset is in third normal form
third_normal(data, max_size = 2)logical value: `TRUE`, if the data is in first normal form, `FALSE` otherwise
If `FALSE` is returned, one of two messages will print: - `"Dataset is NOT in Third Normal Form because it is not in Second Normal Form"` (when data is not in second normal form) - `"Transitive dependency detected"` (when one column depends on a non-key column)
third_normal(auto, max_size=2)
#> [1] "FALSE: Dataset is NOT in Third Normal Form because it is not in Second Normal Form"